==> category-0.9.1.tar.gz: category-0.9.1/category/urls.py <==
#! /usr/bin/env python2.7
# -*- coding: utf-8 -*-

from django.conf.urls import url, patterns

from category.views import CategoryListView, CategoryCreateView
from category.views import CategoryDetailView, CategoryUpdateView
from category.views import TagListView, TagDetailView
from category.views import TagCreateView, TagUpdateView


urlpatterns = patterns(
    '',
    url(
        r'^category/$',
        CategoryListView.as_view(),
        name="category-home"
        ),
    url(
        r'^category/page/(?P<page>\w+)/$',
        CategoryListView.as_view(),
        name="category-home-paginated"
    ),
    url(
        r'^category/add/$',
        CategoryCreateView.as_view(),
        name="category-add"
    ),
    url(
        r'^category/(?P<slug>\w+)/$',
        CategoryDetailView.as_view(),
        name="category-view"
    ),
    url(
        r'^category/(?P<slug>\w+)/update$',
        CategoryUpdateView.as_view(),
        name="category-update"
    ),
)

urlpatterns += patterns(
    '',
    url(
        r'^tag /$',
        TagListView.as_view(),
        name="tag-home"
    ),
    url(
        r'^tag/page/(?P<page>\w+)/$',
        TagListView.as_view(),
        name="tag-home-paginated"
    ),
    url(
        r'^tag/add/$',
        TagCreateView.as_view(),
        name="tag-add"
    ),
    url(
        r'^tag/(?P<slug>[\w-]+)/$',
        TagDetailView.as_view(),
        name="tag-view"
    ),
    url(
        r'^tag/(?P<id>\d+)/update/$',
        TagUpdateView.as_view(),
        name="tag-update"
    ),
)

==> category-0.9.5.tar.gz: category-0.9.5/category/urls.py <==
#! /usr/bin/env python2.7
# -*- coding: utf-8 -*-

from django.conf.urls import url

from category.views import CategoryListView, CategoryCreateView
from category.views import CategoryDetailView, CategoryUpdateView
from category.views import TagListView, TagDetailView
from category.views import TagCreateView, TagUpdateView


urlpatterns = [
    url(
        r'^category/$',
        CategoryListView.as_view(),
        name="category-home"
        ),
    url(
        r'^category/page/(?P<page>\w+)/$',
        CategoryListView.as_view(),
        name="category-home-paginated"
    ),
    url(
        r'^category/add/$',
        CategoryCreateView.as_view(),
        name="category-add"
    ),
    url(r'^category/id/(?P<pk>\d+)/$',
        CategoryDetailView.as_view(), name="category-view"),
    url(r'^category/name/(?P<slug>[-\w]+)/$',
        CategoryDetailView.as_view(), name="category-view"),
    url(
        r'^category/(?P<pk>\w+)/update$',
        CategoryUpdateView.as_view(),
        name="category-update"
    ),
    url(
        r'^category/(?P<slug>\w+)/update$',
        CategoryUpdateView.as_view(),
        name="category-update"
    ),
]

urlpatterns += [
    url(
        r'^tag /$',
        TagListView.as_view(),
        name="tag-home"
    ),
    url(
        r'^tag/page/(?P<page>\w+)/$',
        TagListView.as_view(),
        name="tag-home-paginated"
    ),
    url(
        r'^tag/add/$',
        TagCreateView.as_view(),
        name="tag-add"
    ),
    url(
        r'^tag/(?P<slug>[\w-]+)/$',
        TagDetailView.as_view(),
        name="tag-view"
    ),
    url(
        r'^tag/(?P<id>\d+)/update/$',
        TagUpdateView.as_view(),
        name="tag-update"
    ),
]
